/*
Copyright 2017-2025 Ian Jauslin

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

#include "init.h"
#include "navier-stokes.h"
#include "io.h"
#include <math.h>
#include <stdlib.h>

// random initial condition
int init_random (
  _Complex double* u0,
  int K1,
  int K2,
  int seed
){
  int kx,ky;
  double x,y;

  srand(seed);

  // random init (set half, then the other half are the conjugates)
  for(kx=0;kx<=K1;kx++){
    for(ky=(kx>0 ? -K2 : 1);ky<=K2;ky++){
      x=-0.5+((double) rand())/RAND_MAX;
      y=-0.5+((double) rand())/RAND_MAX;
      u0[klookup_sym(kx,ky,K2)]=x+y*I;
    }
  }

  return 0;
}

// Gaussian initial condition
int init_gaussian (
  _Complex double* u0,
  int K1,
  int K2
){
  int kx,ky;

  for(kx=0;kx<=K1;kx++){
    for(ky=(kx>0 ? -K2 : 1);ky<=K2;ky++){
      u0[klookup_sym(kx,ky,K2)]=(kx*kx+ky*ky)*exp(-(kx*kx+ky*ky));
    }
  }

  return 0;
}

// Initialize from file
// txt input
int init_file_txt (
  _Complex double* u0,
  int K1,
  int K2,
  FILE* initfile
){
  read_vec(u0, K1, K2, initfile);
  return 0;
}
// binary input
int init_file_bin (
  _Complex double* u0,
  int K1,
  int K2,
  FILE* initfile
){
  read_vec_bin(u0, K1, K2, initfile);
  return 0;
}
